<?php
/**
 * Salal functions and definitions
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 * @package Salal
 */
 
if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly.
}

/**
 * Salal only works in WordPress 4.7 or later.
 */
if ( version_compare( $GLOBALS['wp_version'], '4.7-alpha', '<' ) ) {
	require get_template_directory() . '/inc/back-compat.php';
	return;
}

if ( ! function_exists( 'salal_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 * Note that this function is hooked into the after_setup_theme hook, which runs before the init hook. 
	 * The init hook is too late for some features, such as indicating support for post thumbnails.
	 */
	function salal_setup() {
		
		// Set the default content width.
		$GLOBALS['content_width'] = 1120;
		
		// Make theme available for translation.
		load_theme_textdomain( 'salal', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		// Let WordPress manage the document title.
		add_theme_support( 'title-tag' );

		// Classic editor styles
		add_editor_style( array( 'editor-style.css', salal_fonts_url() ) );
		
		// Enable support for Post Thumbnails on posts and pages.
		add_theme_support( 'post-thumbnails' );
		
		// Gutenberg align wide support
		add_theme_support( 'align-wide' );	
		
		// If Set to Large blog
		if( esc_attr(get_theme_mod( 'salal_crop_large_featured', false ) ) ) {
			add_image_size( 'salal-large-post', 1100, 650, true );
		}
		
		// If Set to List Blog
		if( esc_attr(get_theme_mod( 'salal_crop_list_featured', false ) ) ) {	
			add_image_size( 'salal-list-post', 600, 450, true );
		}
		
		// If Set to Grid Blog
		if( esc_attr(get_theme_mod( 'salal_crop_grid_featured', false ) ) ) {
			add_image_size( 'salal-grid-post', 450, 350, true );
		}
		
		// Full post image size
		if( esc_attr(get_theme_mod( 'salal_crop_single_featured', false ) ) ) {
			add_image_size( 'salal-single-post', 1100, 650 );
		}
		
		// Slide images
		if( esc_attr(get_theme_mod( 'salal_display_slider', false ) ) ) {	
			add_image_size( 'salal-slide', 500, 550, true );
		}

		// create recent posts thumbnails
		add_image_size( 'salal-recent', 120, 95, true );
		
		// Add excerpt support to pages
		add_post_type_support( 'page', 'excerpt' );
		
		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'primary' => esc_html__( 'Primary Menu', 'salal' ),
			'footer'  => esc_html__( 'Footer Menu', 'salal' ),
			'social'  => esc_html__( 'Social Icon Menu', 'salal' ),
			'footer-social'  => esc_html__( 'Footer Social Icon Menu', 'salal' ),
		) );

		// Switch default core markup for search form, comment form, and comments to output valid HTML5.
		add_theme_support( 'html5', array(
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'salal_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => get_template_directory_uri() . '/assets/images/default-bg.png',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		// Add support for core custom logo.
		add_theme_support( 'custom-logo', array(
			'height'      => 100,
			'width'       => 300,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'salal_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 * Priority 0 to make it available to lower priority callbacks.
 * @global int $content_width
 */
function salal_content_width() {
	$content_width = $GLOBALS['content_width'];
	// Check if the page has a sidebar.
	if ( is_active_sidebar( 'left-sidebar'  ) || is_active_sidebar( 'right-sidebar' ) || is_active_sidebar( 'blog-sidebar' ) ) {
		$content_width = 725;
	}	
  $GLOBALS['content_width'] = apply_filters( 'salal_content_width', $content_width );
}
add_action( 'template_redirect', 'salal_content_width', 0 );

/**
 * Enqueue admin scripts and styles
 */
function salal_admin_scripts( $hook ) {
	if ( 'post.php' != $hook ) {
        return;
	}
	
	/**
	* Load editor fonts from Google
	*/
	
	wp_enqueue_style( 'salal-admin-fonts', salal_fonts_url(), array(), null );
	
}
add_action( 'admin_enqueue_scripts', 'salal_admin_scripts', 5 );

/**
 * Register Google fonts
 * You can disable from the customizer if you want different fonts.
 * @return string Google fonts URL for the theme.
 */
	 
if ( ! function_exists( 'salal_fonts_url' ) ) :

	function salal_fonts_url() {
		$fonts_url = '';
		$fonts     = array();
		$subsets   = 'latin,latin-ext';

		/* translators: If there are characters in your language that are not supported by Abril Fatface, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Playfair Display font: on or off', 'salal' ) ) {
			$fonts[] = 'Playfair Display:400,700,700i';
		}

		/* translators: If there are characters in your language that are not supported by Kalam, translate this to 'off'. Do not translate into your own language. */
		if ( 'off' !== _x( 'on', 'Kalam font: on or off', 'salal' ) ) {
			$fonts[] = 'Kalam:400';
		}

		if ( $fonts ) {
			$fonts_url = add_query_arg(
				array(
					'family' => urlencode( implode( '|', $fonts ) ),
					'subset' => urlencode( $subsets ),
				), 'https://fonts.googleapis.com/css'
			);
		}

		return esc_url_raw( $fonts_url );
	}
endif;


// Add preconnect for Google Fonts.

function salal_resource_hints( $urls, $relation_type ) {
	if ( wp_style_is( 'salal-fonts', 'queue' ) && 'preconnect' === $relation_type ) {
		$urls[] = array(
			'href' => 'https://fonts.gstatic.com',
			'crossorigin',
		);
	}
		return $urls;
}
add_filter( 'wp_resource_hints', 'salal_resource_hints', 10, 2 );


// Enqueue scripts and styles.
function salal_scripts() {
	
	// Get theme options
	$theme_options = salal_theme_options();
	
	// Get Theme Version.
	$theme_version = wp_get_theme()->get( 'Version' );
	
	// Enable or Disable Google default fonts
	if( esc_attr(get_theme_mod( 'salal_default_google_fonts', true ) ) ) {
		wp_enqueue_style( 'salal-fonts', salal_fonts_url(), array(), null );
	}
	
	// Reset CSS using Bootstrap
	wp_enqueue_style( 'bootstrap-reboot', get_theme_file_uri( '/assets/css/bootstrap-reboot.css' ), '4.1.3', 'screen' );	
	wp_enqueue_style( 'salal-stylesheet', get_stylesheet_uri(), array(), $theme_version );
	
	// Main Menu
	wp_enqueue_script( 'salal-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array( 'jquery' ), '1.0.0', true );	
		wp_localize_script( 'salal-navigation', 'salal_menu_title', salal_get_svg( 'menu' ) . esc_html__( 'Menu', 'salal' ) );
				
	// Owl Slider
	if( esc_attr(get_theme_mod( 'salal_display_slider', false )  ) && is_front_page() || is_home() ) {	
		wp_enqueue_style( 'owl-carousel-css', get_theme_file_uri( '/assets/css/owl-carousel.css' ) );
		wp_enqueue_script( 'owl-carousel-js', get_template_directory_uri() . '/assets/js/owl.carousel.js', array( 'jquery' ), '2.2.1', true );
        wp_enqueue_script( 'salal-theme', get_stylesheet_directory_uri() . '/assets/js/theme.js', array('jquery'), $theme_version, true );        
        $array = array( 
            'rtl'       => is_rtl(),
        ); 
        wp_localize_script( 'salal-theme', 'salal_data', $array );
	}
	
	// Comments script
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'salal_scripts' );


/**
 * Add pingback url on single posts
 */
function salal_pingback_url() {
	if ( is_singular() && pings_open() ) {
		printf( '<link rel="pingback" href="%s">' . "\n", esc_url(get_bloginfo( 'pingback_url' )) );
	}
}
add_action( 'wp_head', 'salal_pingback_url' );



 /*--------------------------------------------------------
 Enqueue Gutenberg editor styles
 -------------------------------------------------------*/
function salal_gutenberg_editor_styles() { 
	wp_enqueue_style( 'salal-gutenberg-editor-styles', get_template_directory_uri() . '/gutenberg-editor.css'); 
}
// only name the function and leave the enqueue as enqueue_block_editor_assets
add_action( 'enqueue_block_editor_assets', 'salal_gutenberg_editor_styles' );


if ( ! function_exists( 'salal_add_gutenberg_features' ) ) {
	function salal_add_gutenberg_features() {
		
	/* Gutenberg Colour Palette */
	$accent_color = get_theme_mod( 'salal_accent_colour' ) ? get_theme_mod( 'salal_accent_colour' ) : '#343f58';
	
    add_theme_support( 'editor-color-palette', array(
			array(
				'name' 	=> _x( 'Accent', 'Name of the accent color in the Gutenberg palette', 'salal' ),
				'slug' 	=> 'accent',
				'color' => esc_attr($accent_color),
			),	
	
        array(
            'name' => esc_html__( 'Dark Grey', 'salal' ),
            'slug' => 'dark-grey',
            'color' => '#161616',
        ),

        array(
            'name' => esc_html__( 'Spice Magenta', 'salal' ),
            'slug' => 'spice-magenta',
            'color' => '#d569a6',
        ),
        array(
            'name' => esc_html__( 'Coffee', 'salal' ),
            'slug' => 'coffee',
            'color' => '#c39f76',
        ),
        array(
            'name' => esc_html__( 'White', 'salal' ),
            'slug' => 'white',
            'color' => '#ffffff',
        ),		
    ) );
	
		/* Gutenberg Font Sizes */
		add_theme_support( 'editor-font-sizes', array(
			array(
				'name' 		=> _x( 'Small', 'Name of the small font size in Gutenberg', 'salal' ),
				'shortName' => _x( 'S', 'Short name of the small font size in the Gutenberg editor.', 'salal' ),
				'size' 		=> 16,
				'slug' 		=> 'small'
			),
			array(
				'name' 		=> _x( 'Regular', 'Name of the regular font size in Gutenberg', 'salal' ),
				'shortName' => _x( 'R', 'Short name of the regular font size in the Gutenberg editor.', 'salal' ),
				'size' 		=> 18,
				'slug' 		=> 'regular'
			),
			array(
				'name' 		=> _x( 'Medium', 'Name of the medium font size in Gutenberg', 'salal' ),
				'shortName' => _x( 'M', 'Short name of the medium font size in the Gutenberg editor.', 'salal' ),
				'size' 		=> 24,
				'slug' 		=> 'medium'
			),			
			array(
				'name' 		=> _x( 'Large', 'Name of the large font size in Gutenberg', 'salal' ),
				'shortName' => _x( 'L', 'Short name of the large font size in the Gutenberg editor.', 'salal' ),
				'size' 		=> 32,
				'slug' 		=> 'large'
			),
			array(
				'name' 		=> _x( 'Larger', 'Name of the larger font size in Gutenberg', 'salal' ),
				'shortName' => _x( 'XL', 'Short name of the larger font size in the Gutenberg editor.', 'salal' ),
				'size' 		=> 48,
				'slug' 		=> 'larger'
			)
		) );		
	
	
	
	
	
	}
}
add_action( 'after_setup_theme', 'salal_add_gutenberg_features' );

// SVG Icons
require get_template_directory() . '/inc/icons.php';

// Include Template Functions.
require get_template_directory() . '/inc/template-functions.php';
require get_template_directory() . '/inc/template-tags.php';
require get_template_directory() . '/inc/post-slider.php';
require get_template_directory() . '/inc/inline-styles.php';
require get_template_directory() . '/inc/customizer/customizer.php';
require get_template_directory() . '/inc/sidebars.php';

// Register recent posts widget
require get_template_directory() . '/inc/recent-posts-widget.php';

// CUSTOMIZER
require get_template_directory() . '/inc/customizer/default-options.php';
require( get_template_directory() . '/inc/customizer/sanitize-functions.php' );

require( get_template_directory() . '/inc/customizer/controls/headline-control.php' );
require( get_template_directory() . '/inc/customizer/controls/upgrade-control.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-basic.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-layout.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-blog.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-post.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-thumbnails.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-slider.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-upgrade.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-colours.php' );
require( get_template_directory() . '/inc/customizer/sections/customizer-typography.php' );

// Load Jetpack compatibility file.
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}
